ArgumentRule class final

A rule that attributes capabilities (and an optional elevated risk) when match applies to the invocation's arguments.

Annotations
  • @immutable

Constructors

ArgumentRule(ArgumentMatch match, Set<CommandCapability> capabilities, {SecurityLevel risk = SecurityLevel.safe, String? description})
Creates an argument rule.
const

Properties

capabilities Set<CommandCapability>
The capabilities attributed when match applies.
final
description String?
An optional human-readable explanation.
final
hashCode int
The hash code for this object.
no setterinherited
match ArgumentMatch
The condition under which this rule fires.
final
risk SecurityLevel
The risk level this argument pattern implies.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited