CommandCapability enum

A discrete capability a command may exercise.

A single command may have several capabilities (for example, git push both reads the filesystem and writes to the network).

Inheritance
Available extensions

Values

readFilesystem → const CommandCapability

Reads files or directory metadata from the filesystem.

writeFilesystem → const CommandCapability

Creates or modifies files on the filesystem.

deleteFilesystem → const CommandCapability

Removes files or directories from the filesystem.

executePrograms → const CommandCapability

Executes other programs or interprets code.

networkRead → const CommandCapability

Reads data from the network (downloads, fetches, clones).

networkWrite → const CommandCapability

Sends data over the network (uploads, pushes, posts).

processManagement → const CommandCapability

Inspects or controls operating-system processes.

privilegeEscalation → const CommandCapability

Escalates privileges (e.g. sudo, su, runas).

systemConfiguration → const CommandCapability

Changes system or security configuration (permissions, ownership, services, registry).

environmentAccess → const CommandCapability

Reads or expands environment variables.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<CommandCapability>
A constant List of the values in this enum, in order of their declaration.