DiagnosticSeverity enum

The severity of a ParseDiagnostic.

Inheritance
Available extensions

Values

info → const DiagnosticSeverity

Informational; does not indicate a problem.

warning → const DiagnosticSeverity

A potential problem that did not prevent parsing.

error → const DiagnosticSeverity

A problem that prevented part (or all) of the input from being parsed.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<DiagnosticSeverity>
A constant List of the values in this enum, in order of their declaration.