ProcessKnowledge class final
Knowledge about process inspection and control commands.
- Implemented types
Constructors
- ProcessKnowledge()
-
Creates the process knowledge plugin.
const
Properties
-
entries
→ List<
CommandKnowledge> -
The command knowledge this plugin contributes.
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
A short identifier for the plugin (used in diagnostics and tests).
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited