RedirectionNode class final

An I/O redirection such as > out.txt, >> log, < in.txt or 2> err.

Inheritance
Annotations
  • @immutable

Constructors

RedirectionNode({required RedirectionType type, required String target})
Creates a redirection node.
const

Properties

children List<CommandNode>
The direct child nodes of this node, in source order.
no setteroverride
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
target String
The redirection target (a filename, or here-doc delimiter), as written.
final
type RedirectionType
The kind of redirection.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override
walk() Iterable<CommandNode>
Visits this node and all of its descendants, depth-first (pre-order).
inherited

Operators

operator ==(Object other) bool
The equality operator.
override