PackageManagerKnowledge class final
Knowledge about software package managers.
Installing/updating packages downloads code from the network, writes it to disk and (for system managers) reconfigures the system — and runs arbitrary install scripts, so it is flagged as a medium risk.
- Implemented types
Constructors
- PackageManagerKnowledge()
-
Creates the package-manager knowledge plugin.
const
Properties
-
entries
→ List<
CommandKnowledge> -
The command knowledge this plugin contributes.
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
A short identifier for the plugin (used in diagnostics and tests).
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited